(this["webpackJsonpray-dashboard-client"]=this["webpackJsonpray-dashboard-client"]||[]).push([[14],{255:function(e,a,t){"use strict";var n=t(223),o=t(180),r=t(0),c=t.n(r),i=Object(n.a)((function(e){return{card:{padding:e.spacing(2),paddingTop:e.spacing(1.5),margin:[e.spacing(2),e.spacing(1)].map((function(e){return"".concat(e,"px")})).join(" ")},title:{fontSize:e.typography.fontSize+2,fontWeight:500,color:e.palette.text.secondary,marginBottom:e.spacing(1)},body:{padding:e.spacing(.5)}}}));a.a=function(e){var a=e.title,t=e.children,n=i();return c.a.createElement(o.a,{className:n.card},c.a.createElement("div",{className:n.title},a),c.a.createElement("div",{className:n.body},t))}},261:function(e,a,t){"use strict";t.d(a,"a",(function(){return n}));var n=function(e){return e<1024?"".concat(e,"KB"):e<Math.pow(1024,2)?"".concat((e/Math.pow(1024,1)).toFixed(2),"KB"):e<Math.pow(1024,3)?"".concat((e/Math.pow(1024,2)).toFixed(2),"MB"):e<Math.pow(1024,4)?"".concat((e/Math.pow(1024,3)).toFixed(2),"GB"):e<Math.pow(1024,5)?"".concat((e/Math.pow(1024,4)).toFixed(2),"TB"):e<Math.pow(1024,6)?"".concat((e/Math.pow(1024,5)).toFixed(2),"TB"):""}},287:function(e,a,t){"use strict";var n=t(1),o=t(2),r=t(0),c=(t(5),t(3)),i=t(4),l=r.forwardRef((function(e,a){var t=e.classes,i=e.className,l=e.component,u=void 0===l?"div":l,d=Object(o.a)(e,["classes","className","component"]);return r.createElement(u,Object(n.a)({ref:a,className:Object(c.a)(t.root,i)},d))}));a.a=Object(i.a)({root:{width:"100%",overflowX:"auto"}},{name:"MuiTableContainer"})(l)},501:function(e){e.exports=JSON.parse('{"a":"1.0.0"}')},519:function(e,a,t){"use strict";t.r(a);var n=t(6),o=t(223),r=t(287),c=t(228),i=t(227),l=t(231),u=t(229),d=t(0),s=t.n(d),m=t(501),f=t(255),p=t(53),b=t(92),v=t(261),g=Object(o.a)((function(e){return{root:{padding:e.spacing(2)},label:{fontWeight:"bold"}}})),h=function(){var e=Object(d.useState)(),a=Object(n.a)(e,2),t=a[0],o=a[1],r=Object(d.useState)([]),c=Object(n.a)(r,2),i=c[0],l=c[1];return Object(d.useEffect)((function(){Object(p.b)("api/ray_config").then((function(e){var a,t;(null===e||void 0===e||null===(a=e.data)||void 0===a||null===(t=a.data)||void 0===t?void 0:t.config)&&o(e.data.data.config)}))}),[]),Object(d.useEffect)((function(){Object(b.b)().then((function(e){var a,t;(null===e||void 0===e||null===(a=e.data)||void 0===a||null===(t=a.data)||void 0===t?void 0:t.summary)&&l(e.data.data.summary)}))}),[]),{rayConfig:t,nodes:i}};a.default=function(){var e=h().rayConfig,a=g();return s.a.createElement("div",{className:a.root},s.a.createElement(f.a,{title:(null===e||void 0===e?void 0:e.clusterName)||"SUMMARY"},s.a.createElement("p",null,"Dashboard Frontend Version: ",m.a),(null===e||void 0===e?void 0:e.imageUrl)&&s.a.createElement("p",null,"Image Url:"," ",s.a.createElement("a",{href:e.imageUrl,target:"_blank",rel:"noopener noreferrer"},e.imageUrl)),(null===e||void 0===e?void 0:e.sourceCodeLink)&&s.a.createElement("p",null,"Source Code:"," ",s.a.createElement("a",{href:e.sourceCodeLink,target:"_blank",rel:"noopener noreferrer"},e.sourceCodeLink))),e&&s.a.createElement(f.a,{title:"Config"},s.a.createElement(r.a,null,s.a.createElement(c.a,null,s.a.createElement(i.a,null,"Key"),s.a.createElement(i.a,null,"Value")),s.a.createElement(l.a,null,Object.entries(e).map((function(e){var t=Object(n.a)(e,2),o=t[0],r=t[1];return s.a.createElement(u.a,null,s.a.createElement(i.a,{className:a.label},o),s.a.createElement(i.a,null,function(e,a){return"containerMemory"===e?Object(v.a)(1024*a*1024):JSON.stringify(a)}(o,r)))}))))))}}}]);
//# sourceMappingURL=14.2d0590ac.chunk.js.map